@@ -2,10 +2,12 @@ from __future__ import annotations
 
 import logging
 from typing import Dict
+from typing import List
 
 import yaml
 
 from pythogen import models
+from pythogen.parsers.inline_schemas_aggregator import InlineSchemasAggregator
 from pythogen.parsers.operations import OperationParser
 from pythogen.parsers.parameters import ParameterParser
 from pythogen.parsers.paths import PathParser
@@ -33,7 +35,8 @@ def parse_openapi_file(file_path: str) -> models.Document:
 
     # Сюда будут складываться найденные в процессе парсинга базовые классы,
     # в которых определён дискриминатор.
-    discriminator_base_class_schemas = []
+    discriminator_base_class_schemas: List[models.DiscriminatorBaseClassSchema] = []
+    inline_schema_aggregator = InlineSchemasAggregator()
 
     ref_resolver = RefResolver(
         openapi_data=openapi_data,
@@ -42,10 +45,12 @@ def parse_openapi_file(file_path: str) -> models.Document:
         ref_resolver=ref_resolver,
         openapi_data=openapi_data,
         discriminator_base_class_schemas=discriminator_base_class_schemas,
+        inline_schema_aggregator=inline_schema_aggregator,
     )
     response_parser = ResponseParser(
         ref_resolver=ref_resolver,
         schema_parser=schema_parser,
+        inline_schema_aggregator=inline_schema_aggregator,
     )
     request_body_parser = RequestBodyParser(
         ref_resolver=ref_resolver,
@@ -70,12 +75,11 @@ def parse_openapi_file(file_path: str) -> models.Document:
         openapi_data=openapi_data,
     )
 
-    parsed_paths = path_parser.parse_collection()
-    parsed_schemas = schema_parser.parse_collection()
-    schemas: Dict[str, models.SchemaObject] = {
-        **parsed_schemas.schemas,
-        **parsed_schemas.inline_schemas,
-        **parsed_paths.inline_schemas,
+    paths = path_parser.parse_collection()
+    schemas = schema_parser.parse_collection()
+    all_schemas: Dict[str, models.SchemaObject] = {
+        **schemas,
+        **inline_schema_aggregator.get_mapping(),
     }
 
     document = models.Document(
@@ -83,8 +87,8 @@ def parse_openapi_file(file_path: str) -> models.Document:
             title=openapi_data['info']['title'],
             version=openapi_data['info']['version'],
         ),
-        paths=parsed_paths.paths,
-        schemas=schemas,
+        paths=paths,
+        schemas=all_schemas,
         parameters=parameters_parser.parse_collections(),
         discriminator_base_class_schemas=discriminator_base_class_schemas,
     )
